@@ -13,20 +13,20 @@
 #  limitations under the License.
 
 
-text_ntype <- function(x, filter = text_filter(x), collapse = FALSE)
+text_ntype <- function(x, filter = NULL, collapse = FALSE, ...)
 {
     with_rethrow({
-        x <- as_text(x, filter = filter)
+        x <- as_corpus_text(x, filter, ...)
         collapse <- as_option("collapse", collapse)
     })
     .Call(C_text_ntype, x, collapse)
 }
 
 
-text_types <- function(x, filter = text_filter(x), collapse = FALSE)
+text_types <- function(x, filter = NULL, collapse = FALSE, ...)
 {
     with_rethrow({
-        x <- as_text(x, filter = filter)
+        x <- as_corpus_text(x, filter, ...)
         collapse <- as_option("collapse", collapse)
     })
     typs <- .Call(C_text_types, x, collapse)
