@@ -15,6 +15,7 @@
 
 abbreviations <- function(kind = "english")
 {
+    .Deprecated("abbreviations_en")
     with_rethrow({
         wordlist(kind, function(k) .Call(C_abbreviations, k))
     })
@@ -23,6 +24,7 @@ abbreviations <- function(kind = "english")
 
 stopwords <- function(kind = "english")
 {
+    .Deprecated("stopwords_en")
     with_rethrow({
         wordlist(kind, function(k) .Call(C_stopwords, k))
     })
