@@ -222,14 +222,15 @@ void corpus_unicode_compose(uint32_t *ptr, size_t *lenptr);
  * Unicode character width type.
  */
 enum corpus_charwidth_type {
-	CORPUS_CHARWIDTH_OTHER = -3,	/**< Control and others:
+	CORPUS_CHARWIDTH_OTHER = -4,	/**< Control and others:
 					  Cc, Cn, Co, Cs, Zl, Zp */
+	CORPUS_CHARWIDTH_EMOJI = -3,    /**< Emoji, wide in most contexts */
 	CORPUS_CHARWIDTH_AMBIGUOUS = -2,/**< can be narrow or wide depending
 					  on the context */
 	CORPUS_CHARWIDTH_IGNORABLE = -1,/**< Default ignorables */
 	CORPUS_CHARWIDTH_NONE = 0,	/**< Combining marks: Mc, Me, Mn */
 	CORPUS_CHARWIDTH_NARROW = 1,	/**< Most western alphabets */
-	CORPUS_CHARWIDTH_WIDE = 2	/**< Most emoji and ideographs */
+	CORPUS_CHARWIDTH_WIDE = 2	/**< Most ideographs */
 };
 
 /**
